@@ -19,11 +19,11 @@ elgy::elgy(QObject *felvnl) : QObject(felvnl)
 	adelk=0;
 %>
 
-elgy::elgy(QObject *felvnl,QString bprl,QString tljsn) : QObject(felvnl)
+elgy::elgy(QObject *felvnl,QString bprl,QString sima) : QObject(felvnl)
 <%
 	adelk=0;
 	kidlgz=bprl;
-	eler=tljsn;
+	eler=sima;
 
 	if(eler.length()>0)
 		irnyjl=QString(SEMANTIK_DIR)+"/flags/"+bprl+ts_202;
