@@ -14,7 +14,7 @@ class elgy: public QObject
 	public:
 		elgy(QObject *felvnl);
 		~elgy();
-		elgy(QObject *felvnl, QString bprl, QString tljsn);
+		elgy(QObject *felvnl, QString bprl, QString sima);
 
 		QString kidlgz;
 		QString eler;
