@@ -13,7 +13,7 @@ class bndkli
 	public:
 		static bndkli* instance();
 
-		static QString zandek(const QString &);
+		static QString fladat(const QString &);
 		static void kivalt(const QString &, const QString &);
 
 		int dolog();
@@ -38,7 +38,7 @@ class bndkli
 		static QMap<QString, QString> kket;
 		static bndkli* eler;
 		QList<bndkli*> mgmnkl;
-		prmza *tqrost;
+		prmza *letsit;
 %>;
 
 int prl();
