@@ -47,7 +47,7 @@ class ablkl : public KXmlGuiWindow
 		void prmz();
 		void kitzjl();
 
-		felu *mozog;
+		felu *mzgat;
 		oszk *lep;
 
 		dbz *eler;
@@ -69,7 +69,7 @@ class ablkl : public KXmlGuiWindow
 		KAction *nybnvn;
 		KToolBar *fnqll;
 		KToolBar *ceco;
-		KToolBar *lecke;
+		KToolBar *munka;
 
 		KMenu *megkap;
 		QAction *elodez;
@@ -81,20 +81,17 @@ class ablkl : public KXmlGuiWindow
 
 		QActionGroup *korrkt;
 
-		QActionGroup *sima;
-		QAction* kapni;
+		QActionGroup *csals;
+		QAction* jo;
 
 		KRecentFilesAction* lnmtat;
 
-		void mzgat(const KUrl&);
+		void mgmozt(const KUrl&);
 
 		QString lmzdul;
 
 		bool queryClose();
 
-		void saveProperties(KConfigGroup &);
-		void readProperties(const KConfigGroup &);
-
 	public slots:
 		void teremt();
 		bool vmrgem();
@@ -110,10 +107,10 @@ class ablkl : public KXmlGuiWindow
 
 		void kelt();
 
-		void mgmozt();
+		void rabir();
 
 		void mgmnkl();
-		void rabir(const QString &, int);
+		void mozog(const QString &, int);
 %>;
 
 #endif
