@@ -1,10 +1,11 @@
 /// Copyright Thomas Nagy 2007
 /// License: QPL
 
+#include <KIcon>
 #include <QtDebug>
 #include <QTreeView>
 #include <QGridLayout>
-#include <QPushButton>
+#include <KPushButton>
 #include <QLineEdit>
 #include <QSizePolicy>
 
@@ -23,8 +24,8 @@ egytr::egytr(QWidget *felvnl,jelzpn *megkap) : QWidget(felvnl)
 	QGridLayout *tqrost=new QGridLayout();
 	jlnrdz=new egykl(this,megkap);
 
-	QPushButton *irnyjl=new QPushButton(this);
-	irnyjl->setIcon(QIcon(ts_255));
+	KPushButton *irnyjl=new KPushButton(this);
+	irnyjl->setIcon(KIcon(ts_255));
 	irnyjl->setIconSize(QSize(22,22));
 	irnyjl->setFlat(1);
 	irnyjl->setFocusPolicy(Qt::NoFocus);
