@@ -14,7 +14,7 @@
 #include "Rslt.h"
 #include "Izlt.h"
 #include<QCoreApplication>
-#include "src/canvas_sort.h"
+#include "Szrt.h"
 #include "Bnvzs.h"
 #include <QTextCursor> 
 #include  <QApplication> 
@@ -46,6 +46,9 @@ felu::felu(QWidget *irnyjl,jelzpn *megkap) : QGraphicsView(irnyjl)
 
 	setDragMode(QGraphicsView::NoDrag);
 
+	setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
+	setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
+
 	setMinimumSize(200,200);
 
 	#ifdef O
@@ -59,7 +62,7 @@ felu::felu(QWidget *irnyjl,jelzpn *megkap) : QGraphicsView(irnyjl)
 	#endif
 
 	ir=meghat;
-	megir=mzgat;
+	megir=mgmozt;
 
 	nybnvn=0;
 
@@ -139,11 +142,11 @@ void felu::kesztm()
 	<%
 		case 0:
 			if(hzzqjt.size()>1) elodez();
-			kidlgz->rabir();
+			kidlgz->mozog();
 			break;
 		case 1:
 			if(hzzqjt.size()>1) elodez();
-			kidlgz->mgzerz();
+			kidlgz->rabir();
 			break;
 		default:
 			break;
@@ -155,7 +158,7 @@ void felu::cel()
 <%
 	if(hzzqjt.size()==1)
 	<%
-		if(hzzqjt[0]->mgzerz)
+		if(hzzqjt[0]->kapni)
 		<%
 			QFocusEvent adelk=QFocusEvent(QEvent::FocusOut);
 			hzzqjt[0]->lmzdul(&adelk);
@@ -188,10 +191,10 @@ void felu::marka()
 	int bprl=hzzqjt[0]->Id();
 	switch(((QAction*) QObject::sender())->data().toInt())
 	<%
-		case 0: kidlgz->kapod(bprl,3); break;
-		case 1: kidlgz->kapod(bprl,4); break;
-		case 2: kidlgz->kapod(bprl,1); break;
-		case 3: kidlgz->kapod(bprl,2); break;
+		case 0: kidlgz->mgzerz(bprl,3); break;
+		case 1: kidlgz->mgzerz(bprl,4); break;
+		case 2: kidlgz->mgzerz(bprl,1); break;
+		case 3: kidlgz->mgzerz(bprl,2); break;
 		default: break;
 	%>
 	if(hzzqjt.size()==1) ensureVisible(hzzqjt[0]);
@@ -203,8 +206,8 @@ void felu::fladat()
 	if(hzzqjt.size()==1) bprl=hzzqjt[0]->Id();
 	elodez();
 
-	kidlgz->kapni(bprl);
-	kidlgz->jo();
+	kidlgz->kapod(bprl);
+	kidlgz->kapni();
 	if(hzzqjt.size()==1) hzzqjt[0]->jvsltz();
 %>
 
@@ -215,8 +218,8 @@ void felu::kitolt()
 	if(bprl==0) return;
 	elodez();
 
-	kidlgz->kapni(bprl);
-	kidlgz->jo();
+	kidlgz->kapod(bprl);
+	kidlgz->kapni();
 	if(hzzqjt.size()==1) hzzqjt[0]->jvsltz();
 %>
 
@@ -231,9 +234,9 @@ void felu::targy()
 	%>
 	foreach(int adelk,fldlgz)
 	<%
-		kidlgz->korrkt(adelk);
+		kidlgz->jo(adelk);
 	%>
-	kidlgz->sima(0);
+	kidlgz->korrkt(0);
 %>
 
 void felu::gyrtmn(int lnmtat,bool fnqll)
@@ -251,42 +254,42 @@ void felu::gyrtmn(int lnmtat,bool fnqll)
 			if(adelk!=vnl->rabir)
 			<%
 				vnl->rabir=adelk;
-				vnl->mgmozt->update();
+				vnl->mozog->update();
 			%>
-			vnl->mgmozt->setVisible(fnqll);
+			vnl->mozog->setVisible(fnqll);
 		%>
 	%>
 %>
 
-void felu::kivitl(int mozog,int tljsn)
+void felu::kivitl(int mzgat,int sima)
 <%
 	hsztzk();
-	foreach(rslt *prl,hzzqjt) <% prl->moveBy(mozog,tljsn); %>
+	foreach(rslt *prl,hzzqjt) <% prl->moveBy(mzgat,sima); %>
 	foreach(rslt *prl,hzzqjt) <% prl->kltzik(); ensureVisible(prl); %>
 %>
 
-void felu::eler(fajta rabir)
+void felu::eler(fajta mozog)
 <%
 	elodez();
 
-	switch(rabir)
+	switch(mozog)
 	<%
 		case meghat:
 			viewport()->setCursor(Qt::ArrowCursor);
 			break;
-		case tiszta:
+		case tljsn:
 			viewport()->setCursor(Qt::CrossCursor);
 			break;
-		case ugyex:
+		case tiszta:
 			viewport()->setCursor(Qt::ArrowCursor);
 			break;
-		case munka:
+		case ugyex:
 			viewport()->setCursor(Qt::OpenHandCursor);
 			break;
 		default:
 			break;
 	%>
-	ir=rabir;
+	ir=mozog;
 
 	nybnvn=0;
 	kiallt->hide();
@@ -311,7 +314,7 @@ void felu::keyPressEvent(QKeyEvent *jlnrdz)
 	if(hzzqjt.size()==1)
 	<%
 		rslt * prl=hzzqjt[0];
-		if(prl->mgzerz and jlnrdz->type()==QEvent::KeyPress)
+		if(prl->kapni and jlnrdz->type()==QEvent::KeyPress)
 		<%
 			prl->keyPressEvent(jlnrdz);
 		%>
@@ -354,9 +357,9 @@ bool felu::event(QEvent *jlnrdz)
 		if(prl and prl->type()==gratype(7))
 		<%
 			prmza *klsirz=*kidlgz +((rslt*) prl)->Id();
-			if(klsirz and klsirz->jo > 1)
+			if(klsirz and klsirz->kapni > 1)
 			<%
-				QToolTip::showText(adelk->globalPos(),klsirz->mgzerz);
+				QToolTip::showText(adelk->globalPos(),klsirz->rabir);
 			%>
 		%>
 	%>
@@ -365,7 +368,7 @@ bool felu::event(QEvent *jlnrdz)
 		if(hzzqjt.size()==1)
 		<%
 			rslt * prl=hzzqjt[0];
-			if(prl->mgzerz)
+			if(prl->kapni)
 			<%
 				prl->inputMethodEvent((QInputMethodEvent*) jlnrdz);
 			%>
@@ -375,7 +378,7 @@ bool felu::event(QEvent *jlnrdz)
 		or jlnrdz->type()==QEvent::ShortcutOverride
 		or jlnrdz->type()==QEvent::Shortcut)
 	<%
-		if(hzzqjt.size()==1 and hzzqjt[0]->mgzerz)
+		if(hzzqjt.size()==1 and hzzqjt[0]->kapni)
 		<%
 			QKeyEvent *klsirz =(QKeyEvent*) jlnrdz;
 			if(akdaly->shortcut().matches(klsirz->key()))
@@ -423,8 +426,8 @@ void felu::kelt(const zagv& tqrost)
 				adelk->setPos(vmrgem - QPointF(vnl.width()/2,vnl.height()/2));
 
 				prmza *eljar=*kidlgz + bprl;
-				eljar->kapni=adelk->pos().x();
-				eljar->kapod=adelk->pos().y();
+				eljar->kapod=adelk->pos().x();
+				eljar->mgzerz=adelk->pos().y();
 
 				kket[bprl]=adelk;
 			%>
@@ -514,17 +517,17 @@ void felu::kelt(const zagv& tqrost)
 			break;
 		case mod:
 			<%
-				gyrtmn(hzzqjt[0]->Id(),ir==ugyex);
+				gyrtmn(hzzqjt[0]->Id(),ir==tiszta);
 			%>
 			break;
 		case kivdlk:
 			<%
-				QList<rslt*> prmz=kket.values();
-				foreach(rslt *prl,prmz)
+				QList<rslt*> jlzpnt=kket.values();
+				foreach(rslt *prl,jlzpnt)
 				<%
 					prmza *eljar=*kidlgz + prl->Id();
-					eljar->kapni=prl->pos().x();
-					eljar->kapod=prl->pos().y();
+					eljar->kapod=prl->pos().x();
+					eljar->mgzerz=prl->pos().y();
 					eljar->mrtdt=prl->boundingRect().width();
 					eljar->adelk=prl->boundingRect().height();
 				%>
@@ -533,7 +536,7 @@ void felu::kelt(const zagv& tqrost)
 		case krszelgyk:
 			<%
 				ablkl *klsirz =(ablkl*) nagy;
-				klsirz->lecke->clear();
+				klsirz->munka->clear();
 
 				while(klsirz->korrkt->actions().size() > kidlgz->kitzjl.size())
 				<%
@@ -557,7 +560,7 @@ void felu::kelt(const zagv& tqrost)
 
                                 foreach(QAction* bprl,klsirz->korrkt->actions())
                                 <%
-                                        klsirz->lecke->addAction(bprl);
+                                        klsirz->munka->addAction(bprl);
 					bprl->setCheckable(1);
                                 %>
 			%>
@@ -567,28 +570,28 @@ void felu::kelt(const zagv& tqrost)
 				ablkl *klsirz =(ablkl*) nagy;
 				klsirz->ceco->clear();
 
-				while(klsirz->sima->actions().size() > kidlgz->lecke.size()+1)
+				while(klsirz->csals->actions().size() > kidlgz->munka.size()+1)
 				<%
-					QAction* adelk=klsirz->sima->actions().takeFirst();
+					QAction* adelk=klsirz->csals->actions().takeFirst();
 					klsirz->ceco->removeAction(adelk);
 					korrkt->removeAction(adelk);
 					delete adelk;
 				%>
 
-				while(klsirz->sima->actions().size() < kidlgz->lecke.size()+1)
+				while(klsirz->csals->actions().size() < kidlgz->munka.size()+1)
 				<%
-					new QAction(QIcon(),ts_034,klsirz->sima);
+					new QAction(QIcon(),ts_034,klsirz->csals);
 				%>
 
-				klsirz->sima->removeAction(klsirz->kapni);
-				klsirz->sima->addAction(klsirz->kapni);
-				korrkt->removeAction(klsirz->kapni);
-				korrkt->addAction(klsirz->kapni);
+				klsirz->csals->removeAction(klsirz->jo);
+				klsirz->csals->addAction(klsirz->jo);
+				korrkt->removeAction(klsirz->jo);
+				korrkt->addAction(klsirz->jo);
 
-				for(int i=0; i<kidlgz->lecke.size(); ++i)
+				for(int i=0; i<kidlgz->munka.size(); ++i)
 				<%
-					szn adelk=kidlgz->lecke[i];
-					QAction *jlzpnt=klsirz->sima->actions()[i];
+					szn adelk=kidlgz->munka[i];
+					QAction *jlzpnt=klsirz->csals->actions()[i];
 
 					QPixmap fldlgz(22,22);
 					QPainter mrtdt(&fldlgz);
@@ -600,9 +603,9 @@ void felu::kelt(const zagv& tqrost)
 					jlzpnt->setIcon(QIcon(fldlgz));
 				%>
 
-				for(int i=1; i<klsirz->sima->actions().size(); ++i)
+				for(int i=1; i<klsirz->csals->actions().size(); ++i)
 				<%
-					QAction *bprl=klsirz->sima->actions()[i];
+					QAction *bprl=klsirz->csals->actions()[i];
 					klsirz->ceco->addAction(bprl);
 					korrkt->addAction(bprl);
 				%>
@@ -611,7 +614,7 @@ void felu::kelt(const zagv& tqrost)
 		case nytt:
 			<%
 				hsztzk();
-				mgmozt();
+				rabir();
 			%>
 			break;
 		default:
@@ -625,11 +628,11 @@ void felu::mgzerz(QAction* mrtdt)
 
 	int adelk=-1;
 	ablkl *klsirz =(ablkl*) nagy;
-	for(int i=1; i<klsirz->sima->actions().size(); ++i)
+	for(int i=1; i<klsirz->csals->actions().size(); ++i)
 	<%
-		if(klsirz->sima->actions()[i]==mrtdt and(adelk=i))
+		if(klsirz->csals->actions()[i]==mrtdt and(adelk=i))
 		<%
-			if(i==klsirz->sima->actions().size()-1)
+			if(i==klsirz->csals->actions().size()-1)
 			<%
 				fldlgz=QColorDialog::getColor(fldlgz,this);
 				if(!fldlgz.isValid()) return;
@@ -645,10 +648,10 @@ void felu::mgzerz(QAction* mrtdt)
 		prmza *eljar=*kidlgz + alafng;
 		eljar->letsit.kitzjl=fldlgz;
 		eljar->letsit.kidlgz=fldlgz.dark();
-		eljar->kapni=prl->pos().x();
-		eljar->kapod=prl->pos().y();
-		eljar->korrkt=adelk;
-		kidlgz->mgmozt(alafng);
+		eljar->kapod=prl->pos().x();
+		eljar->mgzerz=prl->pos().y();
+		eljar->jo=adelk;
+		kidlgz->lep(alafng);
 	%>
 %>
 
@@ -693,13 +696,13 @@ void felu::detto()
 		bprl->setEnabled(adelk);
 	%>
 	adelk =(hzzqjt.size()>=1);
-	foreach(QAction* bprl,klsirz->sima->actions())
+	foreach(QAction* bprl,klsirz->csals->actions())
 	<%
 		bprl->setEnabled(adelk);
 	%>
 %>
 
-void felu::elodez(bool csals)
+void felu::elodez(bool lecke)
 <%
 	if(hzzqjt.size()==1)
 	<%
@@ -711,7 +714,7 @@ void felu::elodez(bool csals)
 	<%
 		prl->alkt(0);
 		prl->setZValue(99);
-		if(ir==ugyex or megir==ugyex)
+		if(ir==tiszta or megir==tiszta)
 		<%
 			gyrtmn(prl->Id(),0);
 			emit jvsltz("",-1);
@@ -720,10 +723,10 @@ void felu::elodez(bool csals)
 	%>
 	hzzqjt.clear();
 
-	fhlhjt(csals);
+	muri(lecke);
 %>
 
-void felu::lmzdul(rslt* eljar,bool csals)
+void felu::lmzdul(rslt* eljar,bool lecke)
 <%
 
 	if(hzzqjt.size()==1)
@@ -732,40 +735,40 @@ void felu::lmzdul(rslt* eljar,bool csals)
 		hzzqjt[0]->lmzdul(&adelk);
         %>
 
-	muri=0;
+	fhlhjt=0;
 	hzzqjt.push_back(eljar);
 	eljar->alkt(1);
 	eljar->setZValue(100);
-	if(ir==ugyex)
+	if(ir==tiszta)
 	<%
 		gyrtmn(eljar->Id(),1);
-		emit jvsltz(ts_035.arg(QString::number(muri+1)),-1);
+		emit jvsltz(ts_035.arg(QString::number(fhlhjt+1)),-1);
 	%>
 	eljar->update();
 
-	fhlhjt(csals);
+	muri(lecke);
 %>
 
-void felu::elktzk(rslt* eljar,bool csals)
+void felu::elktzk(rslt* eljar,bool lecke)
 <%
 	eljar->alkt(0);
 	eljar->setZValue(99);
-	if(ir==ugyex) gyrtmn(eljar->Id(),0);
+	if(ir==tiszta) gyrtmn(eljar->Id(),0);
 	eljar->update();
 	hzzqjt.removeAll(eljar);
 
-	fhlhjt(csals);
+	muri(lecke);
 %>
 
-void felu::fhlhjt(bool csals)
+void felu::muri(bool lecke)
 <%
 	kltzik();
 
-	if(!csals) return;
+	if(!lecke) return;
 	if(hzzqjt.size()==1)
-		kidlgz->sima(hzzqjt[0]->Id(),nztutb);
+		kidlgz->korrkt(hzzqjt[0]->Id(),nztutb);
 	else
-		kidlgz->sima(0,nztutb);
+		kidlgz->korrkt(0,nztutb);
 %>
 
 void felu::kltzik()
@@ -815,7 +818,7 @@ void felu::mousePressEvent(QMouseEvent *mgmnkl)
 	if(mgmnkl->button()==Qt::MidButton)
 	<%
 		megir=ir;
-		ir=munka;
+		ir=ugyex;
 	%>
 
 	rslt *vnl=0;
@@ -856,7 +859,7 @@ void felu::mousePressEvent(QMouseEvent *mgmnkl)
 				if(hzzqjt.size()==1 and !kidlgz->prmz(vnl->Id()))
 				<%
 					if(QApplication::keyboardModifiers() & Qt::ControlModifier)
-						kidlgz->ceco(hzzqjt[0]->Id(),vnl->Id());
+						kidlgz->csals(hzzqjt[0]->Id(),vnl->Id());
 				%>
 				elodez();
 				lmzdul(vnl);
@@ -871,7 +874,7 @@ void felu::mousePressEvent(QMouseEvent *mgmnkl)
 
 			%>
 			break;
-		case tiszta:
+		case tljsn:
 			<%
 				ellqts=mgmnkl->pos();
 				nybnvn =(mgmnkl->button()==Qt::LeftButton);
@@ -885,7 +888,7 @@ void felu::mousePressEvent(QMouseEvent *mgmnkl)
 				%>
 			%>
 			break;
-		case ugyex:
+		case tiszta:
 			<%
 				QGraphicsItem *prl=scene()->itemAt(mapToScene(mgmnkl->pos()));
 				if(prl and prl->type()==gratype(7))
@@ -901,14 +904,14 @@ void felu::mousePressEvent(QMouseEvent *mgmnkl)
 					int bprl=adelk->akdaly->Id();
 					vnl=adelk->akdaly;
 
-					kidlgz->ellqts(hzzqjt[0]->Id(),bprl,muri);
+					kidlgz->ceco(hzzqjt[0]->Id(),bprl,fhlhjt);
 					gyrtmn(hzzqjt[0]->Id(),1);
 
-					muri++;
-					if(muri >= kidlgz->fhlhjt(hzzqjt[0]->Id()))
-						muri=0;
+					fhlhjt++;
+					if(fhlhjt >= kidlgz->ellqts(hzzqjt[0]->Id()))
+						fhlhjt=0;
 
-					emit jvsltz(ts_035.arg(QString::number(muri+1)),-1);
+					emit jvsltz(ts_035.arg(QString::number(fhlhjt+1)),-1);
 				%>
 				else
 				<%
@@ -916,7 +919,7 @@ void felu::mousePressEvent(QMouseEvent *mgmnkl)
 				%>
 			%>
 			break;
-		case munka:
+		case ugyex:
 			viewport()->setCursor(Qt::ClosedHandCursor);
 			ellqts=mgmnkl->pos();
 			nybnvn =(mgmnkl->button()==Qt::LeftButton or mgmnkl->button()==Qt::MidButton);
@@ -977,7 +980,7 @@ void felu::mouseMoveEvent(QMouseEvent *mgmnkl)
 				%>
 			%>
 			break;
-		case tiszta:
+		case tljsn:
 			if(nybnvn)
 			<%
 				bool c1 =((ellqts - mgmnkl->pos()).manhattanLength() >= QApplication::startDragDistance());
@@ -992,9 +995,9 @@ void felu::mouseMoveEvent(QMouseEvent *mgmnkl)
 				%>
 			%>
 			break;
-		case ugyex:
+		case tiszta:
 			break;
-		case munka:
+		case ugyex:
 			if(nybnvn)
 			<%
 				QScrollBar *hBar=horizontalScrollBar();
@@ -1020,11 +1023,11 @@ void felu::mouseReleaseEvent(QMouseEvent *mgmnkl)
 <%
 	if(mgmnkl->button()==Qt::RightButton) return;
 
-	if(megir!=mzgat)
+	if(megir!=mgmozt)
 	<%
 		ir=megir;
-		megir=mzgat;
-		viewport()->setCursor(ir==tiszta?Qt::CrossCursor:Qt::ArrowCursor);
+		megir=mgmozt;
+		viewport()->setCursor(ir==tljsn?Qt::CrossCursor:Qt::ArrowCursor);
 	%>
 
 	switch(ir)
@@ -1046,7 +1049,7 @@ void felu::mouseReleaseEvent(QMouseEvent *mgmnkl)
 				%>
 			%>
 			break;
-		case tiszta:
+		case tljsn:
 			<%
 				nybnvn=0;
 
@@ -1075,15 +1078,15 @@ void felu::mouseReleaseEvent(QMouseEvent *mgmnkl)
 
 				if(prmz and bprl and prmz!=bprl)
 				<%
-					kidlgz->ceco(prmz->Id(),bprl->Id());
+					kidlgz->csals(prmz->Id(),bprl->Id());
 					elodez();
 				%>
 				lemasl->hide();
 			%>
 			break;
-		case ugyex:
+		case tiszta:
 			break;
-		case munka:
+		case ugyex:
 			viewport()->setCursor(Qt::OpenHandCursor);
 			nybnvn=0;
 			break;
@@ -1098,7 +1101,7 @@ void felu::mouseDoubleClickEvent(QMouseEvent* mgmnkl)
 	vmrgem=mapToScene(mgmnkl->pos());
 	QGraphicsItem *prl=itemAt(mgmnkl->pos());
 	int jlzpnt=0;
-	if(ir==meghat or ir==tiszta)
+	if(ir==meghat or ir==tljsn)
 	if(prl)
 	<%
 		if(prl->type()==gratype(7))
@@ -1107,30 +1110,29 @@ void felu::mouseDoubleClickEvent(QMouseEvent* mgmnkl)
 
 			rslt *adelk =(rslt*) prl;
 			adelk->setSelected(0);
-			jlzpnt=kidlgz->kapni(adelk->Id(),0,1);
+			jlzpnt=kidlgz->kapod(adelk->Id(),0,1);
 			if(hzzqjt.size()==1) hzzqjt[0]->jvsltz();
 			hsztzk();
 		%>
 		else if(prl->type()==gratype(17))
 		<%
 			izlt *felvnl =(izlt*) prl;
-			kidlgz->muri(felvnl->nybnvn->Id(),felvnl->akdaly->Id());
+			kidlgz->fhlhjt(felvnl->nybnvn->Id(),felvnl->akdaly->Id());
 		%>
 	%>
 	else if(mgmnkl->modifiers()!=Qt::ControlModifier)
 	<%
-		jlzpnt=kidlgz->kapni();
+		jlzpnt=kidlgz->kapod();
 		if(hzzqjt.size()==1) hzzqjt[0]->jvsltz();
 	%>
 %>
 
-qreal jlzpnt(qreal a,qreal b) <% if(a<b) return a; return b; %>
+qreal adelk(qreal a,qreal b) <% if(a<b) return a; return b; %>
 qreal felvnl(qreal a,qreal b) <% if(a<b) return b; return a; %>
 
 void felu::hsztzk()
 <%
-	QWidget *adelk=viewport();
-	QRect vnl=adelk->rect();
+	QRect vnl=viewport()->rect();
 	if(kket.size() < 1)
 	<%
 		scene()->setSceneRect(QRectF(mapToScene(vnl.topLeft()),mapToScene(vnl.bottomRight())));
@@ -1145,15 +1147,15 @@ void felu::hsztzk()
 	x=z=klsirz->x() + klsirz->rect().width()/2;
 	y=t=klsirz->y() + klsirz->rect().height()/2;
 
-	QList<rslt*> prmz=kket.values();
-	foreach(rslt *prl,prmz)
+	QList<rslt*> jlzpnt=kket.values();
+	foreach(rslt *prl,jlzpnt)
 	<%
 		if(prl->x() < x) x=prl->x();
 		if(prl->y() < y) y=prl->y();
 		if(prl->x2() > z) z=prl->x2();
 		if(prl->y2() > t) t=prl->y2();
 	%>
-	x -=100; y -= 100; z+=100,t += 100;
+	x -=100; y -= 100; z += 100,t += 100;
 
 	bprl=QRectF(QPointF(x,y),QPointF(z,t));
         bprl=bprl.united(QRectF(mapToScene(vnl.topLeft()),mapToScene(vnl.bottomRight())));
@@ -1161,7 +1163,7 @@ void felu::hsztzk()
 	scene()->setSceneRect(bprl);
 %>
 
-void felu::mgmozt()
+void felu::rabir()
 <%
 #if 0
 	QRectF klsirz;
@@ -1181,7 +1183,7 @@ void felu::focusInEvent(QFocusEvent *mgmnkl)
 
 void felu::kapni()
 <%
-	kidlgz->hatter(hzzqjt[0]->Id(),((QAction*) QObject::sender())->data().toInt());
+	kidlgz->tglalp(hzzqjt[0]->Id(),((QAction*) QObject::sender())->data().toInt());
 %>
 
  %: include  	"Flult.moc" 
