@@ -8,6 +8,7 @@
 #include <QLabel>
 #include <QTextBrowser>
 #include <QCoreApplication>
+#include <QWebView>
 #include "Prmza.h"
 #include "Jelzpn.h"
 #include "IztKil.h"
@@ -26,8 +27,10 @@ egyklh::egyklh(QWidget *felvnl,jelzpn *megkap) : QStackedWidget(felvnl)
 	jlzpnt->setText(ts_256);
 	addWidget(jlzpnt);
 
-	adelk=new KHTMLPart(this,this);
+	/*adelk=new KHTMLPart(this,this);
 	irnyjl=adelk->widget();
+	addWidget(irnyjl);*/
+	irnyjl=new QWebView(this);
 	addWidget(irnyjl);
 %>
 
@@ -38,16 +41,20 @@ void egyklh::kelt(const zagv&tqrost)
 	<%
 		case vadrtc:
 			<%
-				QString mrtdt=bndkli::zandek(ts_153);
+				QString mrtdt=bndkli::fladat(ts_153);
 				if(mrtdt.endsWith(ts_257))
 				<%
-					adelk->openUrl(KUrl(mrtdt));
+					if(irnyjl->url()==QUrl(mrtdt))
+						irnyjl->reload();
+					else
+					<%
+						irnyjl->load(QUrl(mrtdt));
+						irnyjl->show();
+					%>
 					setCurrentWidget(irnyjl);
 				%>
 				else if(mrtdt.endsWith(ts_258))
 				<%
-					adelk->openUrl(KUrl(mrtdt));
-					setCurrentWidget(irnyjl);
 				%>
 				else
 				<%
