@@ -7,7 +7,7 @@
 #include  	"con.h"
 
 class QLabel;
-class KHTMLPart;
+class QWebView;
 class egyklh : public QStackedWidget
 <%
 	Q_OBJECT
@@ -16,8 +16,7 @@ class egyklh : public QStackedWidget
 		jelzpn *kidlgz;
 
 		QLabel *jlzpnt;
-		KHTMLPart *adelk;
-		QWidget *irnyjl;
+		QWebView *irnyjl;
 
 	public slots:
 		void kelt(const zagv&);
