@@ -66,55 +66,55 @@ elvs::elvs(jelzpn *megkap)
 	kidlgz=megkap;
 %>
 
-bool elvs::startElement(const QString&,const QString&,const QString& tljsn,const QXmlAttributes& fnqll)
+bool elvs::startElement(const QString&,const QString&,const QString& sima,const QXmlAttributes& fnqll)
 <%
-	if(tljsn==ts_047)
+	if(sima==ts_047)
 	<%
 		kidlgz->mgmnkl=fnqll.value(ts_048);
 
-		if(fnqll.value(ts_049).size()) kidlgz->tiszta=fnqll.value(ts_049);
-		if(fnqll.value(ts_050).size()) kidlgz->ugyex=fnqll.value(ts_050);
-		if(fnqll.value(ts_051).size()) kidlgz->munka=fnqll.value(ts_051);
+		if(fnqll.value(ts_049).size()) kidlgz->tljsn=fnqll.value(ts_049);
+		if(fnqll.value(ts_050).size()) kidlgz->tiszta=fnqll.value(ts_050);
+		if(fnqll.value(ts_051).size()) kidlgz->ugyex=fnqll.value(ts_051);
 	%>
-	else if(tljsn==ts_052)
+	else if(sima==ts_052)
 	<%
 		int a=fnqll.value(ts_053).toInt();
 		int b=fnqll.value(ts_054).toInt();
 		if(!kidlgz->kket.contains(a)) return 0;
 		if(!kidlgz->kket.contains(b)) return 0;
-		kidlgz->ceco(a,b);
+		kidlgz->csals(a,b);
 	%>
-	else if(tljsn==ts_055)
+	else if(sima==ts_055)
 	<%
 		prmza *prl=kidlgz->kket.value(jlzpnt);
 		prl->mgmozt=fnqll.value(ts_056).toInt();
-		prl->jvsltz=fnqll.value(ts_057).toInt();
+		prl->lep=fnqll.value(ts_057).toInt();
 	%>
-	else if(tljsn==ts_058)
+	else if(sima==ts_058)
 	<%
 		prmza *prl=kidlgz->kket.value(jlzpnt);
 		jlszt klsirz;
 		klsirz.mrtdt=fnqll.value(ts_059).toInt();
 		klsirz.jlzpnt=fnqll.value(ts_060).toInt();
-		klsirz.mgzerz=fnqll.value(ts_061);
-		prl->jlnrdz.push_back(klsirz);
+		klsirz.rabir=fnqll.value(ts_061);
+		prl->jvsltz.push_back(klsirz);
 	%>
-	else if(tljsn==ts_062)
+	else if(sima==ts_062)
 	<%
 		jlzpnt=fnqll.value(ts_063).toInt();
 		if(jlzpnt <= 0) return 0;
 
-		kidlgz->kapni(0,jlzpnt);
+		kidlgz->kapod(0,jlzpnt);
 
 		prmza *prl=kidlgz->kket.value(jlzpnt);
 		prl->mzgat=fnqll.value(ts_064);
-		prl->mgzerz=fnqll.value(ts_061);
-		prl->jo=fnqll.value(ts_065).toInt();
-		prl->zandek=fnqll.value(ts_066);
+		prl->rabir=fnqll.value(ts_061);
+		prl->kapni=fnqll.value(ts_065).toInt();
+		prl->hsztzk=fnqll.value(ts_066);
 
 		prl->kivalt=fnqll.value(ts_067);
-		prl->akdaly=fnqll.value(ts_068);
-		prl->tqrost=fnqll.value(ts_069);
+		prl->fladat=fnqll.value(ts_068);
+		prl->nybnvn=fnqll.value(ts_069);
 
 		prl->kket=fnqll.value(ts_070).toInt();
 		if(prl->kket==0) prl->kket=nztsvg;
@@ -122,33 +122,33 @@ bool elvs::startElement(const QString&,const QString&,const QString& tljsn,const
 		prl->mgmnkl=fnqll.value(ts_048);
 
 		prl->mgmozt=fnqll.value(ts_071).toInt();
-		prl->jvsltz=fnqll.value(ts_072).toInt();
+		prl->lep=fnqll.value(ts_072).toInt();
 
 		prl->kitzjl=fnqll.value(ts_073);
 
-		prl->kapni=fnqll.value(ts_074).toDouble();
-		prl->kapod=fnqll.value(ts_075).toDouble();
+		prl->kapod=fnqll.value(ts_074).toDouble();
+		prl->mgzerz=fnqll.value(ts_075).toDouble();
 
-		prl->korrkt=fnqll.value(ts_076).toInt();
+		prl->jo=fnqll.value(ts_076).toInt();
 		prl->letsit.eler=fnqll.value(ts_077);
 		prl->letsit.kitzjl=QColor(fnqll.value(ts_078));
 		prl->letsit.kidlgz=QColor(fnqll.value(ts_079));
 		prl->letsit.jlzpnt=QColor(fnqll.value(ts_080));
 	%>
-	else if(tljsn==ts_081)
+	else if(sima==ts_081)
 	<%
-		kidlgz->lecke.clear();
+		kidlgz->munka.clear();
 	%>
-	else if(tljsn==ts_082)
+	else if(sima==ts_082)
 	<%
 		szn klsirz;
 		klsirz.eler=fnqll.value(ts_083);
 		klsirz.kitzjl=fnqll.value(ts_084);
 		klsirz.kidlgz=fnqll.value(ts_085);
 		klsirz.jlzpnt=fnqll.value(ts_061);
-		kidlgz->lecke.push_back(klsirz);
+		kidlgz->munka.push_back(klsirz);
 	%>
-	else if(tljsn==ts_086)
+	else if(sima==ts_086)
 	<%
 		prmza *prl=kidlgz->kket.value(jlzpnt);
 		prl->prmz.push_back(fnqll.value(ts_063));
@@ -156,7 +156,7 @@ bool elvs::startElement(const QString&,const QString&,const QString& tljsn,const
 	return 1;
 %>
 
-bool elvs::endElement(const QString&,const QString&,const QString& tljsn)
+bool elvs::endElement(const QString&,const QString&,const QString& sima)
 <%
 	return 1;
 %>
@@ -178,49 +178,49 @@ extern "C" <%
  */
 jelzpn::~jelzpn()
 <%
-	tekntt();
-	csals();
+	kulso();
+	lecke();
 	while(!kitzjl.empty())
 	<%
 		delete kitzjl.takeFirst();
 	%>
 %>
 
+void jelzpn::hatlja()
+<%
+	kulso();
+	if(pllnts<1) return;
+	oztaly=new QTimer(this);
+	oztaly->setInterval(pllnts * 60000);
+	connect(oztaly,SIGNAL(timeout()),this,SLOT(tekntt()));
+	oztaly->start();
+%>
+
 void jelzpn::kulso()
 <%
-	tekntt();
-	if(meglns<1) return;
-	tglalp=new QTimer(this);
-	tglalp->setInterval(meglns * 60000);
-	connect(tglalp,SIGNAL(timeout()),this,SLOT(pllnts()));
-	tglalp->start();
+	if(oztaly) oztaly->stop();
+	delete oztaly;
+	oztaly=0;
 %>
 
 void jelzpn::tekntt()
-<%
-	if(tglalp) tglalp->stop();
-	delete tglalp;
-	tglalp=0;
-%>
-
-void jelzpn::pllnts()
 <%
 	m_oLock.lock();
-	if(oztaly.length() > 1)
+	if(meglns.length() > 1)
 	<%
-		QString o=ts_087.arg(oztaly);
-		if(marka(oztaly))
+		QString o=ts_087.arg(meglns);
+		if(kesztm(meglns))
 		<%
-			o=ts_088.arg(oztaly);
+			o=ts_088.arg(meglns);
 		%>
 		emit jvsltz(o,5000);
 	%>
 	m_oLock.unlock();
 %>
 
-void jelzpn::alafng()
+void jelzpn::muri()
 <%
-	lecke.clear();
+	munka.clear();
 
 	QStringList adelk;
 	adelk<<"#fffe8d"<<"#91ffab"<<"#9bfffe"<<"#b8bbff"<<"#e0aaff"<<"#ffa6a6"<<"#ffd8a6"<<"#FFFFFF"<<"#d3d7cf";
@@ -231,24 +231,24 @@ void jelzpn::alafng()
 		szn klsirz;
 		klsirz.kitzjl=QColor(mrtdt);
 		klsirz.eler=ts_089.arg(QString::number(i));
-		lecke.push_back(klsirz);
+		munka.push_back(klsirz);
 		++i;
 	%>
 
 	KConfigGroup jlzpnt(KGlobal::config(),ts_090);
-        mzgat=jlzpnt.readEntry(ts_091,0);
-        detto=jlzpnt.readEntry(ts_092,0);
-	mozog=jlzpnt.readEntry(ts_093,(double) 4.5);
-	meglns=jlzpnt.readEntry(ts_094,0);
+        mgmozt=jlzpnt.readEntry(ts_091,0);
+        alafng=jlzpnt.readEntry(ts_092,0);
+	mzgat=jlzpnt.readEntry(ts_093,(double) 4.5);
+	pllnts=jlzpnt.readEntry(ts_094,0);
 
-	kulso();
+	hatlja();
 
-	zagv tqrost;
-	tqrost.insert(3,QVariant(krsztszn));
-	emit synchro(tqrost);
+	zagv klsirz;
+	klsirz.insert(3,QVariant(krsztszn));
+	emit synchro(klsirz);
 %>
 
-void jelzpn::fajta()
+void jelzpn::detto()
 <%
 	while(!kitzjl.empty())
 	<%
@@ -261,88 +261,88 @@ void jelzpn::fajta()
 		kitzjl.push_back(new elgy(this,mrtdt,mrtdt));
 	%>
 
-	zagv tqrost;
-	tqrost.insert(3,QVariant(krszelgyk));
-	emit synchro(tqrost);
+	zagv klsirz;
+	klsirz.insert(3,QVariant(krszelgyk));
+	emit synchro(klsirz);
 %>
 
-void jelzpn::gyrtmn()
+void jelzpn::fajta()
 <%
 	char sfn[16]="";
 	strcpy(sfn,"/tmp/sem.XXXXXX");
 	char * mrtdt=mkdtemp(sfn);
-	kivitl=mrtdt;
+	gyrtmn=mrtdt;
 
 %>
 
-void jelzpn::csals()
+void jelzpn::lecke()
 <%
 	QProcess mrtdt;
 	QStringList adelk;
-	adelk<<ts_096<<kivitl;
+	adelk<<ts_096<<gyrtmn;
 	mrtdt.start(ts_097,adelk);
 	mrtdt.waitForFinished();
 %>
 
 /* here magic happens */
-QByteArray vnl(const QString & hzzqjt,int nybnvn)
+QByteArray tqrost(const QString & vnl,int hzzqjt)
 <%
-	QByteArray zandek;
-	zandek.fill(0x0,512);
+	QByteArray hsztzk;
+	hsztzk.fill(0x0,512);
 
-	QByteArray akdaly;
-	akdaly.append(hzzqjt);
-	zandek=zandek.replace(0,akdaly.length(),akdaly);
+	QByteArray fladat;
+	fladat.append(vnl);
+	hsztzk=hsztzk.replace(0,fladat.length(),fladat);
 
-	QByteArray tqrost("0000600");
-	zandek.replace(100,tqrost.length(),tqrost);
+	QByteArray nybnvn("0000600");
+	hsztzk.replace(100,nybnvn.length(),nybnvn);
 
 	QByteArray prl("0000000");
-	zandek.replace(108,prl.length(),prl);
+	hsztzk.replace(108,prl.length(),prl);
 
 	QByteArray klsirz("0000000");
-	zandek.replace(116,klsirz.length(),klsirz);
+	hsztzk.replace(116,klsirz.length(),klsirz);
 
 	QByteArray fldlgz;
-	fldlgz.setNum(nybnvn,8);
+	fldlgz.setNum(hzzqjt,8);
 	fldlgz=fldlgz.rightJustified(11,'0');
-	zandek=zandek.replace(124,fldlgz.length(),fldlgz);
+	hsztzk=hsztzk.replace(124,fldlgz.length(),fldlgz);
 
 	QByteArray bprl;
 	qlonglong r=1170500000L;
 	bprl.setNum(r,8);
 	bprl=bprl.rightJustified(11,'0');
-	zandek=zandek.replace(136,bprl.length(),bprl);
+	hsztzk=hsztzk.replace(136,bprl.length(),bprl);
 
 	QByteArray mrtdt;
 	mrtdt.fill(' ',6);
-	zandek=zandek.replace(148,mrtdt.length(),mrtdt);
+	hsztzk=hsztzk.replace(148,mrtdt.length(),mrtdt);
 
 	QByteArray jlzpnt;
 	jlzpnt.fill(' ',1);
-	zandek=zandek.replace(155,jlzpnt.length(),jlzpnt);
+	hsztzk=hsztzk.replace(155,jlzpnt.length(),jlzpnt);
 	jlzpnt.fill('0',1);
-	zandek=zandek.replace(156,jlzpnt.length(),jlzpnt);
+	hsztzk=hsztzk.replace(156,jlzpnt.length(),jlzpnt);
 
 	int adelk=32;
-	for(int i=0; i<512; ++i) adelk += zandek[i];
+	for(int i=0; i<512; ++i) adelk += hsztzk[i];
 	mrtdt.setNum(adelk,8);
 	mrtdt=mrtdt.rightJustified(6,'0');
-	zandek=zandek.replace(148,mrtdt.length(),mrtdt);
+	hsztzk=hsztzk.replace(148,mrtdt.length(),mrtdt);
 
-	return zandek;
+	return hsztzk;
 %>
 
-void jelzpn::jo()
+void jelzpn::kapni()
 <%
-	zagv tqrost;
-	tqrost.insert(3,QVariant(kivdlk));
-	emit synchro(tqrost);
-	foreach(int felept,kket.keys())
+	zagv klsirz;
+	klsirz.insert(3,QVariant(kivdlk));
+	emit synchro(klsirz);
+	foreach(int elrdnz,kket.keys())
 	<%
-		prmza *eljar=kket.value(felept);
-		osszb(felept,(double) eljar->kapni + eljar->mrtdt/2,
-			(double) eljar->kapod + eljar->adelk/2,
+		prmza *eljar=kket.value(elrdnz);
+		osszb(elrdnz,(double) eljar->kapod + eljar->mrtdt/2,
+			(double) eljar->mgzerz + eljar->adelk/2,
 			(double) eljar->mrtdt/2,(double) eljar->adelk/2);
 	%>
 	for(int i=0; i<eler.size(); i++)
@@ -351,14 +351,14 @@ void jelzpn::jo()
 		osszd(mrtdt.x(),mrtdt.y());
 	%>
 
-	hjtg(detto);
+	hjtg(alafng);
 
-	foreach(int felept,kket.keys())
+	foreach(int elrdnz,kket.keys())
 	<%
-		prmza *eljar=kket.value(felept);
-		eljar->kapni=ivdx(felept) - eljar->mrtdt/2;
-		eljar->kapod=ivdy(felept) - eljar->adelk/2;
-		mgmozt(felept);
+		prmza *eljar=kket.value(elrdnz);
+		eljar->kapod=ivdx(elrdnz) - eljar->mrtdt/2;
+		eljar->mgzerz=ivdy(elrdnz) - eljar->adelk/2;
+		lep(elrdnz);
 	%>
 	ugys();
 
@@ -367,21 +367,21 @@ void jelzpn::jo()
 	emit synchro(adelk);
 %>
 
-QString jelzpn::kesztm()
+QString jelzpn::kivitl()
 <%
 	QStringList adelk;
 
 	adelk<<ts_098;
 	adelk<<ts_099;
 	adelk<<ts_100;
-	adelk<<ts_101.arg(bndkli::protectXML(tiszta));
-	adelk<<ts_102.arg(bndkli::protectXML(ugyex));
-	adelk<<ts_103.arg(bndkli::protectXML(munka));
+	adelk<<ts_101.arg(bndkli::protectXML(tljsn));
+	adelk<<ts_102.arg(bndkli::protectXML(tiszta));
+	adelk<<ts_103.arg(bndkli::protectXML(ugyex));
 	adelk<<ts_104.arg(bndkli::protectXML(mgmnkl));
 	adelk<<ts_105;
 
 	adelk<<ts_106;
-	foreach(szn klsirz,lecke)
+	foreach(szn klsirz,munka)
 	<%
 		adelk<<ts_107.arg(
 			klsirz.eler,
@@ -398,26 +398,26 @@ QString jelzpn::kesztm()
 		prmza* prl=fldlgz.at(i);
 		adelk<<ts_109.arg(QString::number(prl->jlzpnt));
 		adelk<<ts_110.arg(bndkli::protectXML(prl->mzgat));
-		adelk<<ts_111.arg(bndkli::protectXML(prl->mgzerz));
-		adelk<<ts_112.arg(QString::number(prl->jo));
-		adelk<<ts_113.arg(bndkli::protectXML(prl->zandek));
+		adelk<<ts_111.arg(bndkli::protectXML(prl->rabir));
+		adelk<<ts_112.arg(QString::number(prl->kapni));
+		adelk<<ts_113.arg(bndkli::protectXML(prl->hsztzk));
 
 		adelk<<ts_114.arg(bndkli::protectXML(prl->kivalt));
-		adelk<<ts_115.arg(bndkli::protectXML(prl->akdaly));
-		adelk<<ts_116.arg(bndkli::protectXML(prl->tqrost));
+		adelk<<ts_115.arg(bndkli::protectXML(prl->fladat));
+		adelk<<ts_116.arg(bndkli::protectXML(prl->nybnvn));
 
 		adelk<<ts_117.arg(QString::number(prl->mgmozt));
-		adelk<<ts_118.arg(QString::number(prl->jvsltz));
+		adelk<<ts_118.arg(QString::number(prl->lep));
 
 		adelk<<ts_119.arg(bndkli::protectXML(prl->kitzjl));
 
 		adelk<<ts_104.arg(bndkli::protectXML(prl->mgmnkl));
 		adelk<<ts_120.arg(QString::number(prl->kket));
 
-		adelk<<ts_121.arg(QString::number(prl->kapod));
-		adelk<<ts_122.arg(QString::number(prl->kapni));
+		adelk<<ts_121.arg(QString::number(prl->mgzerz));
+		adelk<<ts_122.arg(QString::number(prl->kapod));
 
-		adelk<<ts_123.arg(QString::number(prl->korrkt));
+		adelk<<ts_123.arg(QString::number(prl->jo));
 
 		szn klsirz=prl->letsit;
 
@@ -429,13 +429,13 @@ QString jelzpn::kesztm()
 		adelk<<ts_128;
 
 		adelk<<ts_129.arg(
-			QString::number(prl->mgmozt),QString::number(prl->jvsltz));
-		foreach(jlszt klsirz,prl->jlnrdz)
+			QString::number(prl->mgmozt),QString::number(prl->lep));
+		foreach(jlszt klsirz,prl->jvsltz)
 		<%
 			adelk<<ts_130;
 			adelk<<ts_131.arg(QString::number(klsirz.mrtdt));
 			adelk<<ts_132.arg(QString::number(klsirz.jlzpnt));
-			adelk<<ts_111.arg(bndkli::protectXML(klsirz.mgzerz));
+			adelk<<ts_111.arg(bndkli::protectXML(klsirz.rabir));
 			adelk<<ts_105;
 		%>
 
@@ -458,26 +458,26 @@ QString jelzpn::kesztm()
 	return adelk.join("");
 %>
 
-bool jelzpn::marka(QString akdaly)
+bool jelzpn::kesztm(QString nybnvn)
 <%
 
-	zagv tqrost;
-	tqrost.insert(3,QVariant(kivdlk));
-	emit synchro(tqrost);
+	zagv klsirz;
+	klsirz.insert(3,QVariant(kivdlk));
+	emit synchro(klsirz);
 
-	QFile elrdnz(QString(TEMPLATE_DIR)+ts_137);
-	if(!elrdnz.open(QIODevice::ReadOnly))
+	QFile bunda(QString(TEMPLATE_DIR)+ts_137);
+	if(!bunda.open(QIODevice::ReadOnly))
 	<%
-		emit jvsltz(ts_138.arg(elrdnz.fileName()),5000);
+		emit jvsltz(ts_138.arg(bunda.fileName()),5000);
 		return 0;
 	%>
 
-	QByteArray cel=elrdnz.readAll();
-	elrdnz.close();
+	QByteArray akdaly=bunda.readAll();
+	bunda.close();
 
-	bndkli::kivalt(ts_139,kivitl);
-	bndkli::kivalt(ts_140,akdaly);
-	bndkli::kivalt(ts_141,kesztm());
+	bndkli::kivalt(ts_139,gyrtmn);
+	bndkli::kivalt(ts_140,nybnvn);
+	bndkli::kivalt(ts_141,kivitl());
 	bndkli::kivalt(ts_048,mgmnkl);
 	bndkli::kivalt(ts_142,"");
 
@@ -486,61 +486,61 @@ bool jelzpn::marka(QString akdaly)
 		emit jvsltz(ts_143,5000);
 		return 0;
 	%>
-	PyRun_SimpleString(cel.constData());
+	PyRun_SimpleString(akdaly.constData());
 
-	oztaly=akdaly;
+	meglns=nybnvn;
 
 	return 1;
 %>
 
-void jelzpn::amkzrs()
+void jelzpn::marka()
 <%
 	QList<int> k=kket.keys();
 	foreach(int i,k)
 	<%
-		korrkt(i);
+		jo(i);
 	%>
-	kitolt=1;
+	amkzrs=1;
 %>
 
 /* FIXME */ 
-bool jelzpn::kiallt(const QString& akdaly)
+bool jelzpn::kitolt(const QString& nybnvn)
 <%
-	brndez=1;
-	amkzrs();
+	hatter=1;
+	marka();
 
-	QFile elrdnz(QString(FILTER_DIR)+"/main.py");
-	if(!elrdnz.open(QIODevice::ReadOnly))
+	QFile bunda(QString(FILTER_DIR)+"/main.py");
+	if(!bunda.open(QIODevice::ReadOnly))
 	<%
-		emit jvsltz(ts_144.arg(elrdnz.fileName()),5000);
+		emit jvsltz(ts_144.arg(bunda.fileName()),5000);
 		return 0;
 	%>
-	QByteArray cel=elrdnz.readAll();
-	elrdnz.close();
+	QByteArray akdaly=bunda.readAll();
+	bunda.close();
 
-	bndkli::kivalt(ts_139,kivitl);
-	bndkli::kivalt(ts_145,akdaly);
+	bndkli::kivalt(ts_139,gyrtmn);
+	bndkli::kivalt(ts_145,nybnvn);
 	bndkli::kivalt(ts_048,mgmnkl);
-	bndkli::kivalt(ts_142,akdaly);
+	bndkli::kivalt(ts_142,nybnvn);
 
 	if(!prl())
 	<%
 		emit jvsltz(ts_143,5000);
 		return 0;
 	%>
-	PyRun_SimpleString(cel.constData());
+	PyRun_SimpleString(akdaly.constData());
 
 	delete bndkli::eler;
 	bndkli::eler=0;
 
-	bool jlnrdz=lemasl(bndkli::zandek(ts_141));
-	if(!jlnrdz)
+	bool hsztzk=kiallt(bndkli::fladat(ts_141));
+	if(!hsztzk)
 	<%
-		amkzrs();
+		marka();
 		return 0;
 	%>
 
-	QDir mrtdt(kivitl);
+	QDir mrtdt(gyrtmn);
 	QFileInfoList fldlgz=mrtdt.entryInfoList();
 
 	foreach(QFileInfo bprl,fldlgz)
@@ -549,8 +549,8 @@ bool jelzpn::kiallt(const QString& akdaly)
 		if(!jlzpnt.contains(ts_146)) continue;
 		jlzpnt=jlzpnt.section(QRegExp(ts_147),1,1);
 
-		int felept=jlzpnt.toInt();
-		prmza *eljar=kket.value(felept);
+		int elrdnz=jlzpnt.toInt();
+		prmza *eljar=kket.value(elrdnz);
 
 		QString adelk=bprl.absoluteFilePath();
 		if(eljar)
@@ -559,14 +559,14 @@ bool jelzpn::kiallt(const QString& akdaly)
 
 	for(int i=0; i<kket.keys().size(); i++)
 	<%
-		mgmozt(kket.keys().at(i));
+		lep(kket.keys().at(i));
 	%>
 
-	sima(0);
+	korrkt(0);
 
-	zagv tqrost;
-	tqrost.insert(3,QVariant(nytt));
-	emit synchro(tqrost);
+	zagv klsirz;
+	klsirz.insert(3,QVariant(nytt));
+	emit synchro(klsirz);
 
 	zagv adelk;
 	adelk.insert(3,QVariant(krsztszn));
@@ -575,18 +575,18 @@ bool jelzpn::kiallt(const QString& akdaly)
 	QRegExp r(ts_148);
 	QString s(ts_149);
 
-	oztaly=akdaly;
-	oztaly.replace(r,s);
+	meglns=nybnvn;
+	meglns.replace(r,s);
 
-	brndez=0;
+	hatter=0;
 	return 1;
 %>
 
-bool jelzpn::lemasl(const QString &cel)
+bool jelzpn::kiallt(const QString &akdaly)
 <%
 	elvs mrtdt(this);
 	QXmlInputSource bprl;
-	bprl.setData(cel);
+	bprl.setData(akdaly);
 	QXmlSimpleReader fldlgz;
 	fldlgz.setContentHandler(&mrtdt);
 
@@ -598,64 +598,64 @@ bool jelzpn::lemasl(const QString &cel)
 	return 1;
 %>
 
-int jelzpn::kapni(int dolog,int fladat,bool lep)
+int jelzpn::kapod(int cel,int dolog,bool kltzik)
 <%
 
 	int adelk=0;
 
-	if(fladat > 0) adelk=fladat;
-	else adelk=megir();
+	if(dolog > 0) adelk=dolog;
+	else adelk=lemasl();
 
 	prmza *prl=new prmza(this,adelk);
 	kket[adelk]=prl;
 
-	if(lep)
+	if(kltzik)
 	<%
-		prmza *jlzpnt=kket[dolog];
-		prl->korrkt=jlzpnt->korrkt;
+		prmza *jlzpnt=kket[cel];
+		prl->jo=jlzpnt->jo;
 		prl->letsit=jlzpnt->letsit;
 	%>
 
-	zagv tqrost;
-	tqrost.insert(3,QVariant(ossz));
-	tqrost.insert(2,QVariant(adelk));
-	emit synchro(tqrost);
+	zagv klsirz;
+	klsirz.insert(3,QVariant(ossz));
+	klsirz.insert(2,QVariant(adelk));
+	emit synchro(klsirz);
 
-	if(dolog!=0)
+	if(cel!=0)
 	<%
-		ceco(dolog,adelk);
+		csals(cel,adelk);
 	%>
 
-	sima(adelk);
+	korrkt(adelk);
 	return adelk;
 %>
 
-void jelzpn::muri(int fldlgz,int zandek)
+void jelzpn::fhlhjt(int fldlgz,int fladat)
 <%
 
-	eler.removeAll(QPoint(fldlgz,zandek));
-	eler.removeAll(QPoint(zandek,fldlgz));
+	eler.removeAll(QPoint(fldlgz,fladat));
+	eler.removeAll(QPoint(fladat,fldlgz));
 
-	zagv tqrost;
-	tqrost.insert(3,QVariant(nlnc));
-	tqrost.insert(4,QVariant(fldlgz));
-	tqrost.insert(5,QVariant(zandek));
-	emit synchro(tqrost);
+	zagv klsirz;
+	klsirz.insert(3,QVariant(nlnc));
+	klsirz.insert(4,QVariant(fldlgz));
+	klsirz.insert(5,QVariant(fladat));
+	emit synchro(klsirz);
 %>
 
-bool jelzpn::ceco(int targy,int alkt)
+bool jelzpn::csals(int zandek,int targy)
 <%
 
-	if(targy==alkt) return 0;
+	if(zandek==targy) return 0;
 
 	for(int i=0; i<eler.size(); i++)
 	<%
 		QPoint mrtdt=eler.at(i);
-		if(mrtdt.y()==alkt)
+		if(mrtdt.y()==targy)
 			return 0;
 	%>
 
-	int jlzpnt=targy;
+	int jlzpnt=zandek;
 	while(jlzpnt > 0)
 	<%
 		int adelk=0;
@@ -664,7 +664,7 @@ bool jelzpn::ceco(int targy,int alkt)
 			QPoint mrtdt=eler.at(i);
 			if(mrtdt.y()==jlzpnt)
 			<%
-				if(mrtdt.x()==alkt) return 0;
+				if(mrtdt.x()==targy) return 0;
 				adelk=mrtdt.x();
 				break;
 			%>
@@ -672,141 +672,141 @@ bool jelzpn::ceco(int targy,int alkt)
 		jlzpnt=adelk;
 	%>
 
-	eler.append(QPoint(targy,alkt));
+	eler.append(QPoint(zandek,targy));
 
-	zagv tqrost;
-	tqrost.insert(3,QVariant(lnc));
-	tqrost.insert(2,QVariant(alkt));
-	tqrost.insert(0,QVariant(targy));
-	emit synchro(tqrost);
+	zagv klsirz;
+	klsirz.insert(3,QVariant(lnc));
+	klsirz.insert(2,QVariant(targy));
+	klsirz.insert(0,QVariant(zandek));
+	emit synchro(klsirz);
 
 	return 1;
 %>
 
-void jelzpn::korrkt(int lnmtat)
+void jelzpn::jo(int lnmtat)
 <%
 
-	ir(lnmtat);
-	zagv tqrost;
-	tqrost.insert(3,QVariant(oszy));
-	tqrost.insert(2,QVariant(lnmtat));
-	emit synchro(tqrost);
+	megir(lnmtat);
+	zagv klsirz;
+	klsirz.insert(3,QVariant(oszy));
+	klsirz.insert(2,QVariant(lnmtat));
+	emit synchro(klsirz);
 
 	kket.remove(lnmtat);
 %>
 
-void jelzpn::ir(int elodez)
+void jelzpn::megir(int alkt)
 <%
 	for(int i=0; i<eler.size(); i++)
 	<%
 		QPoint mrtdt=eler.at(i);
-		if(mrtdt.x()==elodez or mrtdt.y()==elodez)
+		if(mrtdt.x()==alkt or mrtdt.y()==alkt)
 		<%
-			muri(mrtdt.x(),mrtdt.y());
+			fhlhjt(mrtdt.x(),mrtdt.y());
 			--i;
 		%>
 	%>
 %>
 
-void jelzpn::sima(int lnmtat,int hsztzk)
+void jelzpn::korrkt(int lnmtat,int elodez)
 <%
-	nagy=lnmtat;
-	zagv tqrost;
-	tqrost.insert(3,QVariant(vlsztt));
-	tqrost.insert(2,QVariant(lnmtat));
-	tqrost.insert(jelzpo,QVariant(hsztzk));
-	emit synchro(tqrost);
+	ir=lnmtat;
+	zagv klsirz;
+	klsirz.insert(3,QVariant(vlsztt));
+	klsirz.insert(2,QVariant(lnmtat));
+	klsirz.insert(jelzpo,QVariant(elodez));
+	emit synchro(klsirz);
 %>
 
-QList<int> jelzpn::fortum()
+QList<int> jelzpn::nagy()
 <%
 	QList<int> klsirz=QList<int>();
-	foreach(int felept,kket.keys())
+	foreach(int elrdnz,kket.keys())
 	<%
 		for(int i=0; i<eler.size(); i++)
 		<%
 			QPoint mrtdt=eler.at(i);
-			if(mrtdt.y()==felept) goto end;
+			if(mrtdt.y()==elrdnz) goto end;
 		%>
-		klsirz.push_back(felept);
+		klsirz.push_back(elrdnz);
 		end:;
 	%>
 	qSort(klsirz);
 	return klsirz;
 %>
 
-int jelzpn::leir(int lnmtat)
+int jelzpn::fortum(int lnmtat)
 <%
 	if(lnmtat==0) return 0;
 	for(int i=0; i<eler.size(); i++)
 	<%
 		QPoint mrtdt=eler.at(i);
-		if(mrtdt.y()==lnmtat) return leir(mrtdt.x());
+		if(mrtdt.y()==lnmtat) return fortum(mrtdt.x());
 	%>
 	return lnmtat;
 %>
 
-void jelzpn::mgzerz()
-<%
-	QList<int> klsirz=fortum();
-	if(klsirz.size()==0) return;
-
-	int kivalt=leir(nagy);
-	if(kivalt==0) sima(klsirz[0]);
-
-	for(int i=0; i<klsirz.size(); i++)
-	<%
-		if(klsirz[i]==kivalt)
-		<%
-			if(i==klsirz.size()-1) sima(klsirz[0]);
-			else sima(klsirz[i+1]);
-			return;
-		%>
-	%>
-%>
-
 void jelzpn::rabir()
 <%
-	QList<int> klsirz=fortum();
+	QList<int> klsirz=nagy();
 	if(klsirz.size()==0) return;
 
-	int kivalt=leir(nagy);
-	if(kivalt==0) sima(klsirz[0]);
+	int kivalt=fortum(ir);
+	if(kivalt==0) korrkt(klsirz[0]);
 
 	for(int i=0; i<klsirz.size(); i++)
 	<%
 		if(klsirz[i]==kivalt)
 		<%
-			if(i==0) sima(klsirz[klsirz.size()-1]);
-			else sima(klsirz[i-1]);
+			if(i==klsirz.size()-1) korrkt(klsirz[0]);
+			else korrkt(klsirz[i+1]);
 			return;
 		%>
 	%>
 %>
 
-void jelzpn::rgsztg(int lnmtat)
+void jelzpn::mozog()
+<%
+	QList<int> klsirz=nagy();
+	if(klsirz.size()==0) return;
+
+	int kivalt=fortum(ir);
+	if(kivalt==0) korrkt(klsirz[0]);
+
+	for(int i=0; i<klsirz.size(); i++)
+	<%
+		if(klsirz[i]==kivalt)
+		<%
+			if(i==0) korrkt(klsirz[klsirz.size()-1]);
+			else korrkt(klsirz[i-1]);
+			return;
+		%>
+	%>
+%>
+
+void jelzpn::leir(int lnmtat)
 <%
 	if(lnmtat==0)
 	<%
-		QList<int> klsirz=fortum();
-		if(klsirz.size() > 0) sima(klsirz[0]);
+		QList<int> klsirz=nagy();
+		if(klsirz.size() > 0) korrkt(klsirz[0]);
 	%>
 	else
 	<%
-		int bprl=leir(lnmtat);
-		sima(bprl);
+		int bprl=fortum(lnmtat);
+		korrkt(bprl);
 	%>
 %>
 
-void jelzpn::kapod(int bprl,int jlnrdz)
+void jelzpn::mgzerz(int bprl,int hsztzk)
 <%
 	if(bprl==0)
 	<%
-		rgsztg(0); return;
+		leir(0); return;
 	%>
 	if(!eler.size()) return;
 
-	switch(jlnrdz)
+	switch(hsztzk)
 	<%
 		case 1:
 			<%
@@ -833,7 +833,7 @@ void jelzpn::kapod(int bprl,int jlnrdz)
 					QPoint mrtdt=eler.at(i);
 					if(mrtdt.x()==adelk)
 					<%
-						sima(mrtdt.y());
+						korrkt(mrtdt.y());
 						break;
 					%>
 				%>
@@ -864,7 +864,7 @@ void jelzpn::kapod(int bprl,int jlnrdz)
 					QPoint mrtdt=eler.at(i);
 					if(mrtdt.x()==adelk)
 					<%
-						sima(mrtdt.y());
+						korrkt(mrtdt.y());
 						break;
 					%>
 				%>
@@ -879,7 +879,7 @@ void jelzpn::kapod(int bprl,int jlnrdz)
 					<%
 						prmza *prl=kket.value(mrtdt.x());
 						prl->klsirz=bprl;
-						sima(mrtdt.x());
+						korrkt(mrtdt.x());
 						return;
 					%>
 				%>
@@ -895,7 +895,7 @@ void jelzpn::kapod(int bprl,int jlnrdz)
 					QPoint mrtdt=eler.at(i);
 					if(mrtdt.x()==bprl and mrtdt.y()==adelk)
 					<%
-						sima(mrtdt.y());
+						korrkt(mrtdt.y());
 						return;
 					%>
 				%>
@@ -905,7 +905,7 @@ void jelzpn::kapod(int bprl,int jlnrdz)
 					QPoint mrtdt=eler.at(i);
 					if(mrtdt.x()==bprl)
 					<%
-						sima(mrtdt.y());
+						korrkt(mrtdt.y());
 						return;
 					%>
 				%>
@@ -916,60 +916,60 @@ void jelzpn::kapod(int bprl,int jlnrdz)
 	%>;
 %>
 
-int jelzpn::megir()
+int jelzpn::lemasl()
 <%
-	int adelk=kitolt;
+	int adelk=amkzrs;
 	while(kket.contains(adelk))
 	<%
-		++kitolt;
-		adelk=kitolt;
+		++amkzrs;
+		adelk=amkzrs;
 	%>
 	return adelk;
 %>
 
-void jelzpn::mgmozt(int lnmtat,int hsztzk)
+void jelzpn::lep(int lnmtat,int elodez)
 <%
 	if(!kket.contains(lnmtat)) return;
 
-	zagv tqrost;
-	tqrost.insert(3,QVariant(krszt));
-	tqrost.insert(2,QVariant(lnmtat));
-	tqrost.insert(jelzpo,QVariant(hsztzk));
-	emit synchro(tqrost);
+	zagv klsirz;
+	klsirz.insert(3,QVariant(krszt));
+	klsirz.insert(2,QVariant(lnmtat));
+	klsirz.insert(jelzpo,QVariant(elodez));
+	emit synchro(klsirz);
 %>
 
-void jelzpn::ellqts(int targy,int alkt,int kelt)
+void jelzpn::ceco(int zandek,int targy,int jlnrdz)
 <%
-	int prl=-17;
-	int klsirz=-19;
+	int kivalt=-17;
+	int prl=-19;
 
 	int adelk=0;
 	for(int i=0; i<eler.size(); i++)
 	<%
 		QPoint mrtdt=eler.at(i);
-		if(mrtdt.x()==targy)
+		if(mrtdt.x()==zandek)
 		<%
-			if(adelk==kelt)
+			if(adelk==jlnrdz)
+				kivalt=i;
+			if(mrtdt.y()==targy)
 				prl=i;
-			if(mrtdt.y()==alkt)
-				klsirz=i;
 			adelk++;
 		%>
 
-		if(prl>=0 and klsirz>=0)
+		if(kivalt>=0 and prl>=0)
 		<%
-			if(prl > klsirz)
+			if(kivalt > prl)
 			<%
-				eler.swap(prl,klsirz);
+				eler.swap(kivalt,prl);
 				break;
 			%>
 			else
 			<%
-				int jlzpnt=prl;
-				for(int i=prl+1; i<klsirz+1; i++)
+				int jlzpnt=kivalt;
+				for(int i=kivalt+1; i<prl+1; i++)
 				<%
 					mrtdt=eler.at(i);
-					if(mrtdt.x()==targy)
+					if(mrtdt.x()==zandek)
 						eler.swap(jlzpnt,i);
 				%>
 				break;
@@ -977,82 +977,82 @@ void jelzpn::ellqts(int targy,int alkt,int kelt)
 		%>
 	%>
 
-	zagv tqrost;
-	tqrost.insert(3,QVariant(mod));
-	tqrost.insert(2,QVariant(targy));
-	emit synchro(tqrost);
+	zagv klsirz;
+	klsirz.insert(3,QVariant(mod));
+	klsirz.insert(2,QVariant(zandek));
+	emit synchro(klsirz);
 %>
 
 void jelzpn::set_dirty()
 <%
-	if(!m_bDirty and !brndez)
+	if(!m_bDirty and !hatter)
 	<%
 		m_bDirty=1;
 		emit jvsltz(ts_150,1000);
 	%>
 %>
 
-int jelzpn::prmz(int elodez)
+int jelzpn::prmz(int alkt)
 <%
         for(int i=0; i<eler.size(); i++)
         <%
                 QPoint mrtdt=eler.at(i);
-                if(mrtdt.y()==elodez)
+                if(mrtdt.y()==alkt)
 			return mrtdt.x();
         %>
 	return 0;
 %>
 
-int jelzpn::fhlhjt(int targy)
+int jelzpn::ellqts(int zandek)
 <%
 	int jlzpnt=0;
 	for(int i=0; i<eler.size(); i++)
 	<%
 		QPoint mrtdt=eler.at(i);
-		if(mrtdt.x()==targy) jlzpnt++;
+		if(mrtdt.x()==zandek) jlzpnt++;
 	%>
 	return jlzpnt;
 %>
 
-void jelzpn::hatl(const QString &vmrgem,const QString &bunda,const QString &elktzk)
+void jelzpn::rgsztg(const QString &kelt,const QString &brndez,const QString &vmrgem)
 <%
-	int adelk=ezeltt();
+	int adelk=hatl();
 	if(adelk==0)
 	<%
 		return;
 	%>
 
-	QFile elrdnz(vmrgem);
-	if(!elrdnz.open(QIODevice::ReadOnly))
+	QFile bunda(kelt);
+	if(!bunda.open(QIODevice::ReadOnly))
 	<%
-		emit jvsltz(ts_151.arg(vmrgem),5000);
+		emit jvsltz(ts_151.arg(kelt),5000);
 		return;
 	%>
 
-	QByteArray cel=elrdnz.readAll();
-	elrdnz.close();
+	QByteArray akdaly=bunda.readAll();
+	bunda.close();
 
-	tiszta=elktzk;
+	tljsn=vmrgem;
 
-	bndkli::eler=torekv(adelk);
-	bndkli::kivalt(ts_139,kivitl);
-	bndkli::kivalt(ts_152,elktzk);
-	bndkli::kivalt(ts_145,bunda);
-	bndkli::kivalt(ts_141,kesztm());
+	bndkli::eler=ezeltt(adelk);
+	bndkli::kivalt(ts_139,gyrtmn);
+	bndkli::kivalt(ts_152,vmrgem);
+	bndkli::kivalt(ts_145,brndez);
+	bndkli::kivalt(ts_141,kivitl());
 	bndkli::kivalt(ts_048,mgmnkl);
-	bndkli::kivalt(ts_142,vmrgem);
+	bndkli::kivalt(ts_142,kelt);
 	bndkli::kivalt(ts_153,"");
 
-	sima(0);
+	korrkt(0);
 
-	foreach(int felept,kket.keys())
+	foreach(int elrdnz,kket.keys())
 	<%
-		prmza *eljar=kket.value(felept);
+		prmza *eljar=kket.value(elrdnz);
 		if(eljar->kket!=nztoz2) continue;
-		zagv tqrost;
-		tqrost.insert(3,QVariant(kivdlk3));
-		tqrost.insert(2,QVariant(eljar->jlzpnt));
-		emit synchro(tqrost);
+		zagv klsirz;
+		klsirz.insert(3,QVariant(kivdlk3));
+		klsirz.insert(2,QVariant(eljar->jlzpnt));
+		emit synchro(klsirz);
 	%>
 
 	if(!prl())
@@ -1060,34 +1060,34 @@ void jelzpn::hatl(const QString &vmrgem,const QString &bunda,const QString &elkt
 		emit jvsltz(ts_143,5000);
 		return;
 	%>
-	PyRun_SimpleString(cel.constData());
+	PyRun_SimpleString(akdaly.constData());
 
 	delete bndkli::eler;
 	bndkli::eler=0;
 
-	zagv tqrost;
-	tqrost.insert(3,QVariant(vadrtc));
-	emit synchro(tqrost);
+	zagv klsirz;
+	klsirz.insert(3,QVariant(vadrtc));
+	emit synchro(klsirz);
 %>
 
-bndkli* jelzpn::torekv(int adelk)
+bndkli* jelzpn::ezeltt(int adelk)
 <%
 	bndkli * jlzpnt=new bndkli();
-	jlzpnt->tqrost=kket[adelk];
+	jlzpnt->letsit=kket[adelk];
 
         for(int i=0; i<eler.size(); i++)
         <%
                 QPoint mrtdt=eler.at(i);
                 if(mrtdt.x()!=adelk) continue;
 
-		bndkli *klsirz=torekv(mrtdt.y());
+		bndkli *klsirz=ezeltt(mrtdt.y());
 		jlzpnt->mgmnkl.push_back(klsirz);
         %>
 
 	return jlzpnt;
 %>
 
-int jelzpn::ezeltt()
+int jelzpn::hatl()
 <%
 	int prl=0;
 	int klsirz=0;
@@ -1098,7 +1098,7 @@ int jelzpn::ezeltt()
 		if(prmz(mrtdt.x()) > 0) continue;
 		if(mrtdt.x()==prl) continue;
 
-		int jlzpnt=tamla(mrtdt.x());
+		int jlzpnt=torekv(mrtdt.x());
 		if(jlzpnt > klsirz)
 		<%
 			prl=mrtdt.x();
@@ -1110,26 +1110,26 @@ int jelzpn::ezeltt()
 	return prl;
 %>
 
-int jelzpn::tamla(int adelk)
+int jelzpn::torekv(int adelk)
 <%
 	int kivalt=0;
 	for(int i=0; i<eler.size(); i++)
 	<%
 		QPoint mrtdt=eler.at(i);
 		if(mrtdt.x()==adelk)
-			kivalt += tamla(mrtdt.y());
+			kivalt += torekv(mrtdt.y());
 	%>
 	return ++kivalt;
 %>
 
-QIcon lmzdul(const QString& tljsn,int hatved)
+QIcon elktzk(const QString& sima,int tamla)
 <%
-	QString kivalt=ts_154;
-	QString tqrost=QString::number(hatved);
+	QString letsit=ts_154;
+	QString kivalt=QString::number(tamla);
 	QStringList klsirz=QString(ICONS).split(':');
 	foreach(QString mrtdt,klsirz)
 	<%
-		QString prl=mrtdt+"/"+kivalt+"/"+tqrost+"x"+tqrost+"/actions/"+tljsn+".png";
+		QString prl=mrtdt+"/"+letsit+"/"+kivalt+"x"+kivalt+"/actions/"+sima+".png";
 		if(!QFileInfo(prl).isReadable()) continue;
 
 		QIcon jlzpnt=QIcon(prl);
@@ -1141,9 +1141,9 @@ QIcon lmzdul(const QString& tljsn,int hatved)
 
 atalak::atalak() : QXmlDefaultHandler() <%%>
 
-bool atalak::startElement(const QString&,const QString&,const QString& tljsn,const QXmlAttributes& fnqll)
+bool atalak::startElement(const QString&,const QString&,const QString& sima,const QXmlAttributes& fnqll)
 <%
-	if(tljsn==ts_155)
+	if(sima==ts_155)
 	<%
 		kidlgz<<ts_156;
 	%>
@@ -1154,25 +1154,25 @@ bool atalak::startElement(const QString&,const QString&,const QString& tljsn,con
 
 jelzpn::jelzpn(QObject* felvnl) : QObject(felvnl)
 <%
-	kitolt=1;
-	nagy=0;
-	tiszta="";
-	meglns=21 / 4;
-	brndez=0;
+	amkzrs=1;
+	ir=0;
+	tljsn="";
+	pllnts=21 / 4;
+	hatter=0;
 
-	tglalp=0;
+	oztaly=0;
+	tiszta="";
 	ugyex="";
-	munka="";
-	gyrtmn();
+	fajta();
 %>
 
-bool atalak::endElement(const QString&,const QString&,const QString& tljsn)
+bool atalak::endElement(const QString&,const QString&,const QString& sima)
 <%
-	if(tljsn==ts_053)
+	if(sima==ts_053)
 	<%
 		kidlgz<<ts_157<<kket<<ts_158;
 	%>
-	else if(tljsn==ts_155)
+	else if(sima==ts_155)
 	<%
 		kidlgz<<kket<<ts_159;
 	%>
@@ -1190,16 +1190,16 @@ prmza* jelzpn::operator+(const int y)
 	return kket.value(y);
 %>
 
-void jelzpn::hatter(int lnmtat,int kltzik)
+void jelzpn::tglalp(int lnmtat,int lmzdul)
 <%
 	if(lnmtat <= 0) return;
 
-	kket.value(lnmtat)->kket=kltzik;
+	kket.value(lnmtat)->kket=lmzdul;
 
-	zagv tqrost;
-	tqrost.insert(3,QVariant(kivdlk2));
-	tqrost.insert(2,QVariant(lnmtat));
-	emit synchro(tqrost);
+	zagv klsirz;
+	klsirz.insert(3,QVariant(kivdlk2));
+	klsirz.insert(2,QVariant(lnmtat));
+	emit synchro(klsirz);
 %>
 
 #include "Jelzpn.moc"
