@@ -17,21 +17,21 @@ prmza::prmza(jelzpn *megkap,int lnmtat)
 	kket=nztsvg;
 
 	jlzpnt=lnmtat;
-	korrkt=0;
+	jo=0;
 	kidlgz=megkap;
 	mzgat=ts_000;
-	mgzerz="";
-	zandek="";
+	rabir="";
+	hsztzk="";
 	kitzjl="";
 
 	kivalt="";
-	akdaly="";
-	tqrost="";
+	fladat="";
+	nybnvn="";
 
 	klsirz=0;
 
 	mgmozt=0;
-	jvsltz=0;
+	lep=0;
 %>
 
 /*!
@@ -49,46 +49,46 @@ bool prmza::eler(const QString & bprl)
 	return 1;
 %>
 
-szn& prmza::nybnvn()
+szn& prmza::akdaly()
 <%
 	if(kidlgz->prmz(jlzpnt) <= 0)
 	<%
-		return kidlgz->lecke[0];
+		return kidlgz->munka[0];
 	%>
-	if(korrkt < 0)
+	if(jo < 0)
 	<%
 		return letsit;
 	%>
-	if(korrkt==kidlgz->lecke.size())
+	if(jo==kidlgz->munka.size())
 	<%
 		return letsit;
 	%>
-	if(korrkt > kidlgz->lecke.size())
+	if(jo > kidlgz->munka.size())
 	<%
 		return letsit;
 	%>
-	if(korrkt==0)
+	if(jo==0)
 	<%
-		return kidlgz->lecke[1];
+		return kidlgz->munka[1];
 	%>
-	return kidlgz->lecke[korrkt];
+	return kidlgz->munka[jo];
 %>
 
 szn& prmza::felvnl()
 <%
-	if(korrkt < 0)
+	if(jo < 0)
 	<%
 		return letsit;
 	%>
-	if(korrkt==kidlgz->lecke.size())
+	if(jo==kidlgz->munka.size())
 	<%
 		return letsit;
 	%>
-	if(korrkt > kidlgz->lecke.size())
+	if(jo > kidlgz->munka.size())
 	<%
 		return letsit;
 	%>
-	return kidlgz->lecke[korrkt];
+	return kidlgz->munka[jo];
 %>
 
 /*
