@@ -19,7 +19,7 @@ class jlszt
 	public:
 	int mrtdt;
 	int jlzpnt;
-	QString mgzerz;
+	QString rabir;
 %>;
 
 class jlzlt 
@@ -36,20 +36,20 @@ class prmza
 		jelzpn* kidlgz;
 
 		QString mzgat;
-		QString mgzerz;
-		int jo;
-		QString zandek;
+		QString rabir;
+		int kapni;
+		QString hsztzk;
 
 		QString kivalt;
-		QString akdaly;
-		QString tqrost;
+		QString fladat;
+		QString nybnvn;
 
 		QPixmap fnqll;
 		QPixmap dolog;
 
 		int jlzpnt;
-		double kapni;
 		double kapod;
+		double mgzerz;
 		double mrtdt;
 		double adelk;
 
@@ -57,18 +57,18 @@ class prmza
 
 		QList<QString> prmz;
 
-		int korrkt;
+		int jo;
 		int klsirz; 
 		szn letsit;
 
-		szn& nybnvn();
+		szn& akdaly();
 		szn& felvnl();
 
 		QString kitzjl;
 
 		int mgmozt;
-		int jvsltz;
-		QList<jlszt> jlnrdz;
+		int lep;
+		QList<jlszt> jvsltz;
 		QString mgmnkl;
 
 		bool eler(const QString &);
