@@ -52,7 +52,7 @@ ude \
 
 #define zagv QHash<int, QVariant>
 
-qreal jlzpnt(qreal a, qreal b);
+qreal adelk(qreal a, qreal b);
 qreal felvnl(qreal a, qreal b);
 
 /* TODO: values hardcoded in some places */
