@@ -28,24 +28,24 @@ elgyk::elgyk(felu *fldlgz,rslt *alkt)
 	: QGraphicsRectItem(),korrkt(fldlgz)
 <%
 	setFlags(ItemIsMovable & ItemIsSelectable);
-	tqrost=alkt;
+	letsit=alkt;
 	setRect(0,0,19,19);
 
 	/* set the z value to 51 */
 	setZValue(51);
 
         fldlgz->scene()->addItem(this);
-	setParentItem(tqrost);
+	setParentItem(letsit);
 %>
 
 void elgyk::paint(QPainter *adelk,const QStyleOptionGraphicsItem *bprl,QWidget * irnyjl)
 <%
 	int alafng=0;
-	for(int i=0; i<tqrost->prmz.size(); ++i)
+	for(int i=0; i<letsit->prmz.size(); ++i)
 	<%
-		if(this==tqrost->prmz[i]) <% alafng=i; break; %>
+		if(this==letsit->prmz[i]) <% alafng=i; break; %>
 	%>
-	prmza *mrtdt=korrkt->kidlgz->kket.value(tqrost->Id());
+	prmza *mrtdt=korrkt->kidlgz->kket.value(letsit->Id());
 	QString jlzpnt=mrtdt->prmz[alafng];
 
 	for(int i=0; i<korrkt->kidlgz->kitzjl.size(); ++i)
@@ -59,3 +59,8 @@ void elgyk::paint(QPainter *adelk,const QStyleOptionGraphicsItem *bprl,QWidget *
 	%>
 %>
 
+#if WAF
+#else
+#include "Flult.moc"
+#endif
+
