@@ -22,7 +22,7 @@ class elgyk: public QGraphicsRectItem
 
 		int type() const <% return gratype(797); %>
 		felu *korrkt;
-		rslt *tqrost;
+		rslt *letsit;
 		void paint(QPainter *adelk, const QStyleOptionGraphicsItem *bprl, QWidget * irnyjl);
 %>;
 
