@@ -41,21 +41,21 @@ szrtrd::szrtrd(dbz *megkap)
 	kidlgz = megkap;
 %>
 
-bool szrtrd::startElement(const QString&, const QString&, const QString& tljsn, const QXmlAttributes& fnqll)
+bool szrtrd::startElement(const QString&, const QString&, const QString& sima, const QXmlAttributes& fnqll)
 <%
-	if (tljsn == ts_165)
+	if (sima == ts_165)
 	<%
 		rsltb *klsirz = new rsltb(kidlgz);
 		kidlgz->kket.push_back(klsirz);
 		klsirz->jlzpnt = fnqll.value(ts_063).toInt();
 		kidlgz->jo = 1 + qMax(kidlgz->jo, klsirz->jlzpnt);
-		klsirz->mzgat->setPlainText(fnqll.value(ts_061));
+		klsirz->mgmozt->setPlainText(fnqll.value(ts_061));
 		klsirz->setBrush(QColor(fnqll.value(ts_060)));
 
 		klsirz->bprl(fnqll.value(ts_075).toFloat(), fnqll.value(ts_074).toFloat());
 		klsirz->setRect(QRectF(0., 0., fnqll.value(ts_166).toDouble(), fnqll.value(ts_167).toDouble()));
 	%>
-	else if (tljsn == ts_168)
+	else if (sima == ts_168)
 	<%
 		izltb *klsirz = new izltb(kidlgz);
 		klsirz->elodez = fnqll.value(ts_169).toInt();
@@ -94,7 +94,7 @@ bool szrtrd::startElement(const QString&, const QString&, const QString& tljsn,
 		kidlgz->eler.push_back(klsirz);
 		korrkt = klsirz;
 	%>
-	else if (tljsn == ts_173)
+	else if (sima == ts_173)
 	<%
 		if (korrkt)
 		<%
@@ -106,9 +106,9 @@ bool szrtrd::startElement(const QString&, const QString&, const QString& tljsn,
 	return 1;
 %>
 
-bool szrtrd::endElement(const QString&, const QString&, const QString& tljsn)
+bool szrtrd::endElement(const QString&, const QString&, const QString& sima)
 <%
-	if (tljsn == ts_168)
+	if (sima == ts_168)
 	<%
 		if (korrkt) korrkt->vmrgem();
 		korrkt = 0;
@@ -252,8 +252,8 @@ void dbz::kelt(const zagv& tqrost)
 					prmza *eljar = kidlgz->kket.value(fldlgz);
 					if (eljar != 0 and eljar->kket == nztoz2)
 					<%
-						if (!kidlgz->brndez)
-							eljar->kitzjl = sima();
+						if (!kidlgz->hatter)
+							eljar->kitzjl = tljsn();
 					%>
 				%>
 				kapni();
@@ -277,7 +277,7 @@ void dbz::kelt(const zagv& tqrost)
 				<%
 					break;
 				%>
-				eljar->kitzjl = sima();
+				eljar->kitzjl = tljsn();
 			%>
 			break;
 		case kivdlk3:
@@ -303,7 +303,7 @@ void dbz::kelt(const zagv& tqrost)
 				scene()->render(&mrtdt, adelk, vnl);
 				mrtdt.end();
 
-				bprl.save(QString(kidlgz->kivitl + ts_186 +
+				bprl.save(QString(kidlgz->gyrtmn + ts_186 +
 					ts_187).arg(QString::number(jlzpnt)));
 				kapni();
 				jlzpnt = fldlgz;
@@ -764,7 +764,7 @@ void dbz::cel()
 	if (hzzqjt.size() == 1 and hzzqjt[0]->type() == gratype(37))
 	<%
 		rsltb *klsirz = (rsltb*) hzzqjt[0];
-		if (klsirz->mgzerz)
+		if (klsirz->kapni)
 		<%
 			QFocusEvent adelk = QFocusEvent(QEvent::FocusOut);
 			klsirz->lmzdul(&adelk);
@@ -830,14 +830,14 @@ void dbz::kapni()
 	%>
 %>
 
-QString dbz::sima()
+QString dbz::tljsn()
 <%
 	QStringList l;
 	l<<ts_188;
 	foreach (rsltb *adelk, kket)
 	<%
 		l<<ts_189.arg(QString::number(adelk->jlzpnt));
-		l<<ts_111.arg(bndkli::protectXML(adelk->mzgat->toPlainText()));
+		l<<ts_111.arg(bndkli::protectXML(adelk->mgmozt->toPlainText()));
 		l<<ts_190.arg(
 				QString::number(adelk->pos().x()),
 				QString::number(adelk->pos().y()),
@@ -880,7 +880,7 @@ void dbz::keyPressEvent(QKeyEvent *jlnrdz)
 	if (hzzqjt.size() == 1 and hzzqjt[0]->type() == gratype(37))
 	<%
 		rsltb * prl = (rsltb*) hzzqjt[0];
-		if (prl->mgzerz and jlnrdz->type() == QEvent::KeyPress)
+		if (prl->kapni and jlnrdz->type() == QEvent::KeyPress)
 		<%
 			setCursor(Qt::ArrowCursor);
 			prl->keyPressEvent(jlnrdz);
@@ -907,9 +907,9 @@ bool dbz::event(QEvent *jlnrdz)
 		if (prl and prl->type() == gratype(7))
 		<%
 			prmza *klsirz = *kidlgz + ((rslt*) prl)->Id();
-			if (klsirz and klsirz->jo > 1)
+			if (klsirz and klsirz->kapni > 1)
 			<%
-				QToolTip::showText(adelk->globalPos(), klsirz->mgzerz);
+				QToolTip::showText(adelk->globalPos(), klsirz->rabir);
 			%>
 		%>
 	%>
@@ -920,7 +920,7 @@ bool dbz::event(QEvent *jlnrdz)
 		if (hzzqjt.size() == 1 and hzzqjt[0]->type() == gratype(37))
 		<%
 			rsltb *prl = (rsltb*) hzzqjt[0];
-			if (prl->mgzerz)
+			if (prl->kapni)
 			<%
 				QKeyEvent *klsirz = (QKeyEvent*) jlnrdz;
 				if (akdaly->shortcut().matches(klsirz->key()))
@@ -938,7 +938,7 @@ bool dbz::event(QEvent *jlnrdz)
 		if (hzzqjt.size() == 1 and hzzqjt[0]->type() == gratype(37))
 		<%
 			rsltb * prl = (rsltb*) hzzqjt[0];
-			if (prl->mgzerz)
+			if (prl->kapni)
 			<%
 				prl->inputMethodEvent((QInputMethodEvent*) jlnrdz);
 			%>
