@@ -18,12 +18,12 @@ class rsltb : public QGraphicsRectItem
 		int type() const <% return gratype(37); %>
 
 		void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *);
-                QTextDocument *mzgat;
+                QTextDocument *mgmozt;
                 QTextCursor *meghat;
-		bool mgzerz;
+		bool kapni;
 
-		qreal kapni;
 		qreal kapod;
+		qreal mgzerz;
 
 		void kitzjl(qreal, qreal);
 		void bprl(QPointF hsztzk);
